/**
 * A schema context.
 * @memberof module:pon-schema/lib
 * @inner
 * @constructor PonSchema
 * @param {object} def
 */

"use strict";

var jjv = require('jjv'),
    extend = require('extend');

/** @lends PonSchema */
function PonSchema(def) {
    var s = this;
    if (def instanceof PonSchema) {
        def = def.toJSON();
    }
    s.def = def || {};
}

PonSchema.prototype = {
    def: undefined,
    /**
     * Validate values.
     * @param {object} values - Values to validate.
     * @returns {object|null} - Validation errors.
     */
    validate: function (values) {
        var s = this,
            env = jjv();
        var errors = env.validate(s.def, values);
        return errors && errors['validation'] || null;
    },
    /**
     * Convert to json object.
     */
    toJSON: function () {
        var s = this;
        return extend({}, s.def);
    }
};

module.exports = PonSchema;
