/**
 * Test case for ponSchema.
 * Runs with mocha.
 */

var PonSchema = require('../lib/pon_schema.js'),
    assert = require('assert');

describe('pon-schema', function suite() {

    before(function setup(done) {
        done();
    });

    after(function teardown(done) {
        done();
    });


    it('Pon schema', function (done) {
        var schema = new PonSchema({
            type: 'object',
            properties: {
                firstname: {
                    type: 'string',
                    minLength: 2,
                    maxLength: 15
                },
                lastname: {
                    type: 'string',
                    minLength: 2,
                    maxLength: 25
                }
            },
            required: ['firstname', 'lastname']
        });
        var result01 = schema.validate({
            firstname: 'foo'
        });
        assert.deepEqual(result01, {
            lastname: {required: true}
        });

        var result02 = schema.validate({
            firstname: 'foo',
            lastname: 'bar'
        });
        assert.equal(result02, null);
        done();
    });

    it('From schema.', function () {
        var schema01 = new PonSchema({
            title: 'foo'
        });
        var schema02 = new PonSchema(schema01);
        assert.ok(schema01);
        assert.ok(schema01.def.title, 'foo');
        assert.ok(schema02);
        assert.ok(schema02.def.title, 'foo');
    });
});

